# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`ntpd`](#ntpd): Set up ntpd in either standalone or server mode
* [`ntpd::ntpdate`](#ntpdntpdate): Manage the setup of ``ntpdate``

**Defined types**

* [`ntpd::allow`](#ntpdallow): Allow access to this server from a particular address or netmask

## Classes

### ntpd

Set up ntpd in either standalone or server mode

* **See also**
ntp.conf(5)

#### Parameters

The following parameters are available in the `ntpd` class.

##### `ntpd_options`

Data type: `String[1]`

Options for the ntp daemon, put into `/etc/sysconfig/ntpd`

##### `servers`

Data type: `Ntpd::Servers`

An array of servers or a Hash of server/option pairs providing details
for the NTP servers that this system should synchronize with

* **Example**

  ```
  servers => {
    'time.local.net' => ['iburst','minpoll 4', 'prefer'],
    # This one will just use $default_options
    'time.other.net' => []
  }
  ```

Default value: simplib::lookup('simp_options::ntpd::servers', { 'default_value' => {} })

##### `stratum`

Data type: `Integer[0]`

The stratum for this system

* This only comes into play if no external servers are defined and the
  stratum has to be fudged

Default value: 2

##### `logconfig`

Data type: `Array[String[1]]`

A list of options for refining the system log output

Default value: ['=syncall','+clockall']

##### `broadcastdelay`

Data type: `Numeric`

Default calibration delay

Default value: 0.004

##### `default_options`

Data type: `Array[String[1]]`

The default options that will be added to all servers

* Set to an empty array to disable

Default value: ['minpoll 4','maxpoll 4','iburst']

##### `default_restrict`

Data type: `Array[Ntpd::Restrict]`

The default IPv4 ``restrict`` options

Default value: ['kod', 'nomodify', 'notrap', 'nopeer', 'noquery']

##### `default_restrict6`

Data type: `Array[Ntpd::Restrict]`

The default IPv6 ``restrict`` options

Default value: $default_restrict

##### `admin_hosts`

Data type: `Array[Simplib::IP::V4]`

Hosts that are allowed unrestricted access via IPv4

Default value: ['127.0.0.1']

##### `admin_hosts6`

Data type: `Array[Simplib::IP::V6]`

Hosts that are allowed unrestricted access via IPv6

Default value: ['::1']

##### `discard`

Data type: `Optional[Ntpd::Discard]`

An optional has that can be used to set the average,minimum and
monitor options for ``discard``

Default value: `undef`

##### `disable_monitor`

Data type: `Boolean`

Disable the monitoring facility to prevent amplification attacks using
``ntpdc monlist`` command when default restrict does not include the
``noquery`` flag

* See CVE-2013-5211 for details

Default value: `true`

##### `manage_ntpdate`

Data type: `Boolean`

Manage ntpdate settings

Default value: `true`

##### `trusted_nets`

Data type: `Optional[Simplib::Netlist]`

Setting this to an Array of networks/hostnames that you trust for
communication will enable a default ``ntpd::alow`` entry so that remote
systems can query this system for time.

Default value: `undef`

##### `default_restrict_rules`

Data type: `Optional[Array[Ntpd::Restrict]]`

Set to an Array of ``restrict`` rules of your choosing

* Has no effect if ``$trusted_nets`` is not set

Default value: `undef`

##### `firewall`

Data type: `Boolean`

Enable management of the firewall in relation to inbound communication

* Has no effect if ``$trusted_nets`` is not set

Default value: simplib::lookup('simp_options::firewall', { 'default_value' => false})

##### `ntpdate_servers`

Data type: `Ntpd::Servers`

NTP servers that are used in the ntpdate script at startup

Default value: $servers

##### `ntpdate_sync_hwclock`

Data type: `Boolean`

Set to `true` to sync hw clock after successful ntpdate. Set in
`/etc/sysconfig/ntpdate`

Default value: `true`

##### `ntpdate_retry`

Data type: `Integer[0]`

Number of retries before giving up. Set in `/etc/sysconfig/ntpdate`

Default value: 2

##### `ntpdate_options`

Data type: `Optional[String[1]]`

Options for ntpdate. Set in `/etc/sysconfig/ntpdate`

Default value: `undef`

##### `auditd`

Data type: `Boolean`

Enable auditd monitoring of the ntp configuration files

* This probably isn't needed in most cases since Puppet controls these
  files, but some systems require it

Default value: simplib::lookup('simp_options::auditd', { 'default_value' => false})

##### `package_ensure`

Data type: `String`

`ensure` parameter for the `ntp` package

Default value: simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })

##### `extra_content`

Data type: `Optional[String[1]]`

An unvalidated String that will be appended to the configuration file

Default value: `undef`

##### `config_content`

Data type: `Optional[String[1]]`

The entire content of the configuration file. ALL OTHER ntpd CONFIGURATION
OPTIONS WILL BE IGNORED.

* NOTE: Calls to ``ntpd::allow`` will still add ``restrict`` lines to the
  configuration.

Default value: `undef`

### ntpd::ntpdate

Manage the setup of ``ntpdate``

## Defined types

### ntpd::allow

Allow access to this server from a particular address or netmask

#### Parameters

The following parameters are available in the `ntpd::allow` defined type.

##### `rules`

Data type: `Optional[Variant[
    String[1],Array[Ntpd::Restrict]
  ]]`

A standard ``ntpd.conf`` restrict rule (``notrust``, etc...)

Default value: `undef`

##### `trusted_nets`

Data type: `Simplib::Netlist`

Networks and Hosts to allow

Default value: simplib::lookup('simp_options::trusted_nets', { 'default_value' => ['127.0.0.1', '::1'] })

##### `firewall`

Data type: `Boolean`

If enabled, allow connections from `trusted_nets`

Default value: simplib::lookup('simp_options::firewall', { 'default_value' => false})

